/**
 * CTU Open 2018
 * Problem Solution: Lost Houses
 *
 * @author Josef Cibulka
 */

#include <cassert>
#include <iostream>
#include <vector>
#include <set>

using namespace std;

struct Point
{
  int64_t x,y;
};

int64_t sqr (int64_t a)
{
  return a*a;
}

bool operator< (const Point &p1, const Point &p2)
{
  if (p1.y != p2.y)
    return (p1.y < p2.y);
  else 
    return (p1.x < p2.x);
}

Point find_nearest(const vector<Point> &pts, const Point &center, int64_t *dst_sq)
{
  *dst_sq = -1;
  Point res {0,0};
  for (Point pt : pts)
  {
    int64_t pt_dst = sqr(pt.x - center.x) + sqr(pt.y - center.y);
    if (*dst_sq < 0 || pt_dst < *dst_sq)
    {
      *dst_sq = pt_dst;
      res = pt;
    }
  }
  assert(*dst_sq > 0);
  return res;
}

// Point 90° to the right from pt when viewed from center.
Point right_90(Point center, Point pt)
{
  int resx = center.x + (pt.y - center.y);
  int resy = center.y - (pt.x - center.x);
  return Point {resx, resy};
}

// The top of square with given bottom and left vertices.
Point top_vertex(Point bottom, Point left)
{
  int resx = left.x + (left.y - bottom.y);
  int resy = left.y - (left.x - bottom.x);
  return Point {resx, resy};
}

int main(void)
{
  int size;
  while (cin >> size)
  { 
    size *= 4;
    int64_t area = 0;
    // The set of all points sorted by y-coordinate.
    set<Point> ptset;
    for (int i=0; i<size; ++i)
    {
      int x,y;
      cin >> x >> y;
      Point newpt {x,y};
      ptset.insert(newpt);
    }
    while (!ptset.empty())
    {
      Point bottom = *(ptset.begin());
      ptset.erase(ptset.begin());
      vector<Point> cands;
      for (Point pt: ptset)
      {
        if(ptset.find(right_90(bottom, pt)) == ptset.end())
          continue;
        cands.push_back(pt);
      }
      int64_t dst_sq;
      Point left = find_nearest(cands, bottom, &dst_sq);
      area += dst_sq;
      ptset.erase(ptset.find(left));
      ptset.erase(ptset.find(right_90(bottom, left)));
      ptset.erase(ptset.find(top_vertex(bottom, left)));
    }

    cout << area << endl;
  }
  return 0;
}
